Separator

Struct Separator 

pub struct Separator { /* private fields */ }
A UI component that acts as a separator typically a horizontal line. Separator components are displayed in the order they are added to a Container. Each Separator can have a different style, specified using the SeparatorStyle enum. There are two types of separators available: normal and dotted.

Notes

  • A normal separator looks like this: -------
  • A dotted separator looks like this: - - - -

Usage

The Separator component is useful for dividing sections in your terminal UI.

Implementations

Source

impl Separator

pub fn normal(style: SeparatorStyle) -> Self

Creates a standard (non-dotted) Separator with the given style.

Parameters
  • style: The visual style of the separator, specified as a SeparatorStyle.
Returns

Separator: A new Separator instance.

Example
// Create a normal separator with a solid style.
let _ = Separator::normal(SeparatorStyle::Solid);
pub fn dotted(style: SeparatorStyle) -> Self

Creates a dotted Separator with the given style.

Parameters
  • style: The visual style of the separator, specified as a SeparatorStyle.
Returns

Separator: A new Separator instance.

Example
// Create a dotted separator with a solid style.
let _ = Separator::dotted(SeparatorStyle::Solid);