Module error

Module error 

Provides custom error types and a result type alias for error handling in Feather-TUI.

Enums

FtuiError
An enum representing all possible errors that can occur in Feather-TUI.

Type Aliases

FtuiResult
A convenient alias for Result<T, FtuiError>.