A generic trigger handler for evaluating conditions based on stored arguments.
Structs
- Trigger
- A generic trigger handler for evaluating conditions.
Triggerallows you to define a condition as a function, associate it with an optional argument, and check whether the condition is met.
Functions
- cast_
arg - Casts the argument of a trigger function to the specified type.