A generic callback handler for executing functions with stored arguments.
Structs
- Callback
- A generic callback handler for executing functions with stored arguments.
Callbackallows you to associate a function with an optional argument and invoke it later.
Functions
- cast_
arg - Casts the argument of a callback function to the specified type.