Module trigger

A generic trigger handler for evaluating conditions based on stored arguments.

Structs

Trigger
A generic trigger handler for evaluating conditions based on stored arguments. Trigger allows you to define a condition as a function, associate it with an argument, and check whether the condition is met.