pub struct Trigger { /* private fields */ }Expand description
A generic trigger handler for evaluating conditions based on stored arguments.
Trigger allows you to define a condition as a function, associate it with
an argument, and check whether the condition is met.
Usage
Trigger is use for creating a Selector object.
Example
use feather_tui as tui;
tui::tui_trg_new_trigger_func!(trigger, arg, {
arg.downcast_ref::<u32>().unwrap() == 5
});
let mut trig = tui::trg::Trigger::new(trigger, 5u32);
trig.check(); // Condition is met return True
trig.update_arg(6);
trig.check(); // Condition no longer met return FalseImplementations